@@ -126,7 +126,11 @@ def compatibilize_metadata(metadata):
 
         return metadata
         
-    metadata_version = metadata["SPTpython version"]
+    if "SPTpython version" in metadata.keys():
+        metadata_version = metadata["SPTpython version"]
+    else:
+        metadata_version = metadata["pySPT version"]
+    
     callbacks = []
     
     for version in version_metadata_changes.keys():
@@ -316,6 +320,18 @@ def get_num_traj_per_msd_point(metadata, data_dfs):
 def get_time_str():
     return datetime.datetime.now().strftime("%b_%d_%Y_%H_%M_%S")
 
+def match_video_file(file, group_idx=None):
+    # regex match video file name, returning corresponding group, if desired
+    regex = r'nf(\d+)_d(\d+\.?\d+)_e(\d+\.?\d+)_p(\d+\.?\d+)_NDTiffStack(\d*)\.tif$'
+    if not group_idx:
+        result = re.search(regex, file)
+        if result:
+            return True
+        return False
+    else:
+        return re.search(regex, file).group(group_idx+1)
+
+    
 def N_gaussian(x, *args):
     As = args[0::3]
     sigs = args[1::3]
@@ -406,7 +422,7 @@ def rolling_average(x,n):
     cumsum = np.cumsum(np.insert(x, 0, 0)) 
     return (cumsum[n:] - cumsum[:-n]) / float(n)
 
-def search_regex_id(s, depth = 0):
+def search_regex_id(s, depth = 0, group = True):
     # depth is how far back the path is from the metadata.json file
     # depth > 0
     
@@ -434,12 +450,14 @@ def search_regex_id(s, depth = 0):
                     found_idx = idx
                     break
             to_add = ""
+            # Vapor percentage specified (or other information)
+            if not group and re.search(r'\d+ ?(?:s|ms) ?(.+)', parts[len(parts)-3+depth]):
+                to_add += "-" + re.search(r'\d+ ?(?:s|ms) ?(.+)', parts[len(parts)-3+depth]).group(1)
             if found_idx != -1 and found_idx + 4 - depth < len(parts):
                 # concatenate subfolders containing more metadata
                 # e.g.: extract "ambient" from subpath path
                 # s = M7.5_X6.5_T1_L0.002\ambient\test\400ms\nf500_d400.0_e400.0_p96.0_NDTiffStack1_Apr_15_2025_11_27_27\metadata.json
-                to_add = '-'.join(parts[found_idx+1:len(parts)-3+depth])
-                to_add = '-' + to_add
+                to_add += '-' + '-'.join(parts[found_idx+1:len(parts)-3+depth])
             return regex_match.group(1) + to_add
 
     return ''
@@ -593,14 +611,7 @@ def truncate_emitters_by_frame(emitters: pd.DataFrame, frame: int, inclusive=Tru
         
     return subset
 
-def verify_original_video_file(file):
-    # regex matches .tif file naming convention
-    to_match = '^nf\d+_d\d+\.\d+_e\d+\.\d+_p\d+\.\d+_NDTiffStack\d*\.tif$'
-    result = re.search(to_match, file)
-    if result:
-        return True
-    return False
-    
+
 def verify_file_format(s: str):
     """
     Common format in video acquisition:
@@ -693,5 +704,7 @@ def visualize_particle(trajectories, metadata, particle, frames_list = None, par
         return tifViewer
 
 if __name__ == '__main__':
-    fig, ax = get_figure(2,2)
+    path = r'D:\Northwestern University\RCH-WANG-GROUP - Documents\ORG-RSRCH-WANG-GROUP\Sync to Lab Computers\Chris\M7.5_X6.5_T1_L0.1\EtOH\400 ms 20%\nf500_d400_e400_p96_NDTiffStack1_May_14_2025_13_27_29'
+    print(search_regex_id(path, depth=1))
+    # fig, ax = get_figure(2,2)
     
\ No newline at end of file
